@@ -1,7 +1,7 @@
 from __future__ import print_function
 
 __author__ = 'Lei Xu <eddyxu@gmail.com>'
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 __classifiers__ = [
     'Development Status :: 2 - Pre-Alpha',
@@ -10,7 +10,9 @@ __classifiers__ = [
     'Operating System :: OS Independent',
     'Programming Language :: Python',
     'Topic :: Internet :: WWW/HTTP',
-    'Topic :: Software Development :: Libraries']
+    'Topic :: Software Development :: Libraries',
+    'Topic :: Software Development :: Quality Assurance',
+    'Topic :: Utilities']
 
 __copyright__ = '2013, %s ' % __author__
 __license__ = """
